==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/client/foundation/block/BigOutlines.java <==
package com.zurrtum.create.client.foundation.block;

import com.zurrtum.create.catnip.math.VecHelper;
import com.zurrtum.create.client.AllExtensions;
import com.zurrtum.create.client.catnip.animation.AnimationTickHolder;
import com.zurrtum.create.client.foundation.utility.RaycastHelper;
import net.minecraft.class_2338;
import net.minecraft.class_243;
import net.minecraft.class_2680;
import net.minecraft.class_310;
import net.minecraft.class_3965;
import net.minecraft.class_5134;
import net.minecraft.class_746;

public class BigOutlines {
    static class_3965 result = null;

    public static void pick(class_310 mc) {
        if (!(mc.field_1719 instanceof class_746 player))
            return;
        if (mc.field_1687 == null)
            return;

        result = null;

        class_243 origin = player.method_5836(AnimationTickHolder.getPartialTicks(mc.field_1687));

        double maxRange = mc.field_1765 == null ? Double.MAX_VALUE : mc.field_1765.method_17784().method_1025(origin) + 0.5;

        double range = player.method_45325(class_5134.field_47758);
        class_243 target = RaycastHelper.getTraceTarget(player, Math.min(maxRange, range) + 1, origin);

        RaycastHelper.rayTraceUntil(
            origin, target, pos -> {
                class_2338.class_2339 p = class_2338.field_10980.method_25503();

                for (int x = -1; x <= 1; x++) {
                    for (int y = -1; y <= 1; y++) {
                        for (int z = -1; z <= 1; z++) {
                            p.method_10103(pos.method_10263() + x, pos.method_10264() + y, pos.method_10260() + z);
                            class_2680 blockState = mc.field_1687.method_8320(p);

                            if (!AllExtensions.BIG_OUTLINE.contains(blockState.method_26204()))
                                continue;

                            class_3965 hit = blockState.method_26224(mc.field_1687, p).method_1092(origin, target, p.method_10062());
                            if (hit == null)
                                continue;

                            if (result != null && class_243.method_24953(p).method_1025(origin) >= class_243.method_24953(result.method_17777())
                                .method_1025(origin))
                                continue;

                            class_243 vec = hit.method_17784();
                            double interactionDist = vec.method_1025(origin);
                            if (interactionDist >= maxRange)
                                continue;

                            class_2338 hitPos = hit.method_17777();

                            // pacifies ServerGamePacketListenerImpl.handleUseItemOn
                            vec = vec.method_1020(class_243.method_24953(hitPos));
                            vec = VecHelper.clampComponentWise(vec, 1);
                            vec = vec.method_1019(class_243.method_24953(hitPos));

                            result = new class_3965(vec, hit.method_17780(), hitPos, hit.method_17781());
                        }
                    }
                }

                return result != null;
            }
        );

        if (result != null)
            mc.field_1765 = result;
    }
}

==> create-fly-6.0.8-1.21.10-2-sources.jar: com/zurrtum/create/client/foundation/block/BigOutlines.java <==
package com.zurrtum.create.client.foundation.block;

import com.zurrtum.create.catnip.math.VecHelper;
import com.zurrtum.create.client.AllExtensions;
import com.zurrtum.create.client.catnip.animation.AnimationTickHolder;
import com.zurrtum.create.client.foundation.utility.RaycastHelper;
import net.minecraft.class_2338;
import net.minecraft.class_243;
import net.minecraft.class_2680;
import net.minecraft.class_310;
import net.minecraft.class_3965;
import net.minecraft.class_5134;
import net.minecraft.class_746;

public class BigOutlines {
    static class_3965 result = null;

    public static void pick(class_310 mc) {
        if (!(mc.method_1560() instanceof class_746 player))
            return;
        if (mc.field_1687 == null)
            return;

        result = null;

        class_243 origin = player.method_5836(AnimationTickHolder.getPartialTicks(mc.field_1687));

        double maxRange = mc.field_1765 == null ? Double.MAX_VALUE : mc.field_1765.method_17784().method_1025(origin) + 0.5;

        double range = player.method_45325(class_5134.field_47758);
        class_243 target = RaycastHelper.getTraceTarget(player, Math.min(maxRange, range) + 1, origin);

        RaycastHelper.rayTraceUntil(
            origin, target, pos -> {
                class_2338.class_2339 p = class_2338.field_10980.method_25503();

                for (int x = -1; x <= 1; x++) {
                    for (int y = -1; y <= 1; y++) {
                        for (int z = -1; z <= 1; z++) {
                            p.method_10103(pos.method_10263() + x, pos.method_10264() + y, pos.method_10260() + z);
                            class_2680 blockState = mc.field_1687.method_8320(p);

                            if (!AllExtensions.BIG_OUTLINE.contains(blockState.method_26204()))
                                continue;

                            class_3965 hit = blockState.method_26224(mc.field_1687, p).method_1092(origin, target, p.method_10062());
                            if (hit == null)
                                continue;

                            if (result != null && class_243.method_24953(p).method_1025(origin) >= class_243.method_24953(result.method_17777())
                                .method_1025(origin))
                                continue;

                            class_243 vec = hit.method_17784();
                            double interactionDist = vec.method_1025(origin);
                            if (interactionDist >= maxRange)
                                continue;

                            class_2338 hitPos = hit.method_17777();

                            // pacifies ServerGamePacketListenerImpl.handleUseItemOn
                            vec = vec.method_1020(class_243.method_24953(hitPos));
                            vec = VecHelper.clampComponentWise(vec, 1);
                            vec = vec.method_1019(class_243.method_24953(hitPos));

                            result = new class_3965(vec, hit.method_17780(), hitPos, hit.method_17781());
                        }
                    }
                }

                return result != null;
            }
        );

        if (result != null)
            mc.field_1765 = result;
    }
}
